@@ -798,7 +798,9 @@ def test_basic_ldapagent(topology_st, import_example_ldif):
     log.info('test_basic_ldapagent: PASSED')
 
 
-def test_basic_dse(topology_st, import_example_ldif):
+@pytest.mark.skipif(not get_user_is_ds_owner(),
+                    reason="process ownership permission is required")
+def test_basic_dse_survives_kill9(topology_st, import_example_ldif):
     """Tests that the dse.ldif is not wiped out after the process is killed (bug 910581)
 
     :id: 10f141da-9b22-443a-885c-87271dcd7a59
@@ -819,7 +821,9 @@ def test_basic_dse(topology_st, import_example_ldif):
 
     dse_file = topology_st.standalone.confdir + '/dse.ldif'
     pid = check_output(['pidof', '-s', 'ns-slapd']).strip()
-    check_output(['sudo', 'kill', '-9', ensure_str(pid)])
+    # We can't guarantee we have access to sudo in any environment ... Either
+    # run py.test with sudo, or as the same user as the dirsrv.
+    check_output(['kill', '-9', ensure_str(pid)])
     if os.path.getsize(dse_file) == 0:
         log.fatal('test_basic_dse: dse.ldif\'s content was incorrectly removed!')
         assert False
@@ -866,7 +870,7 @@ def test_mod_def_rootdse_attr(topology_st, import_example_ldif, rootdse_attr):
 
    :id: c7831e04-f458-4e23-83c7-b6f66109f639
 
-   :setup: Standalone instance and we are using rootdse_attr fixture which 
+   :setup: Standalone instance and we are using rootdse_attr fixture which
 adds nsslapd-return-default-opattr attr with value of one operation attribute.
 
    :steps:
@@ -1088,6 +1092,107 @@ def test_critical_msg_on_empty_range_idl(topology_st):
     # Step 5
     assert not topology_st.standalone.searchErrorsLog('CRIT - list_candidates - NULL idl was recieved from filter_candidates_ext.')
 
+def audit_pattern_found(server, log_pattern):
+    file_obj = open(server.ds_paths.audit_log, "r")
+
+    found = None
+    # Use a while true iteration because 'for line in file: hit a
+    log.info('Audit log contains')
+    while True:
+        line = file_obj.readline()
+        log.info(line)
+        found = log_pattern.search(line)
+        if ((line == '') or (found)):
+            break
+
+    return found
+
+@pytest.mark.ds50026
+def test_ticketldbm_audit(topology_st):
+    """When updating LDBM config attributes, those attributes/values are not listed
+    in the audit log
+
+    :id: 5bf75c47-a283-430e-a65c-3c5fd8dbadb8
+    :setup: Standalone Instance
+    :steps:
+        1. Enable audit log
+        2. Update a set of config attrs in LDBM config
+        3. Disable audit log (to restore the default config)
+        4. Check that config attrs are listed in the audit log
+    :expectedresults:
+        1. Should succeeds
+        2. Should succeeds
+        3. Should succeeds
+        4. Should succeeds
+    """
+    inst = topology_st[0]
+
+    inst.config.enable_log('audit')
+
+    #inst.ds_paths.audit_log
+    attrs = ['nsslapd-lookthroughlimit', 'nsslapd-pagedidlistscanlimit', 'nsslapd-idlistscanlimit', 'nsslapd-db-locks']
+    mods = []
+    for attr in attrs:
+        mods.append((ldap.MOD_REPLACE, attr, b'10001'))
+    inst.modify_s(DN_CONFIG_LDBM, mods)
+    inst.config.enable_log('audit')
+
+    for attr in attrs:
+        log.info("Check %s is replaced in the audit log" % attr)
+        regex = re.compile("^replace: %s" % attr)
+        assert audit_pattern_found(inst, regex)
+
+
+def test_dscreate(request):
+    """Test that dscreate works, we need this for now until setup-ds.pl is
+    fully discontinued.
+
+    :id: 5bf75c47-a283-430e-a65c-3c5fd8dbadb9
+    :setup: None
+    :steps:
+        1. Create template file for dscreate
+        2. Create instance using template file
+    :expectedresults:
+        1. Should succeeds
+        2. Should succeeds
+    """
+
+    template_file = "dssetup.inf"
+    template_text = """[general]
+config_version = 2
+full_machine_name = localhost.localdomain
+
+
+[slapd]
+instance_name = test_dscreate
+root_dn = cn=directory manager
+root_password = someLongPassword_123
+
+[backend-userroot]
+suffix = dc=example,dc=com
+sample_entries = yes
+"""
+
+    with open(template_file, "w") as template_fd:
+        template_fd.write(template_text)
+    cmd = 'dscreate from-file ' + template_file
+
+    try:
+        subprocess.check_output(cmd, shell=True, stderr=subprocess.STDOUT)
+    except subprocess.CalledProcessError as e:
+        log.fatal("dscreate failed!  Error ({}) {}".format(e.returncode, e.output))
+        assert False
+
+    def fin():
+        os.remove(template_file)
+        try:
+            subprocess.check_output('dsctl test_dscreate remove --do-it', shell=True)
+        except subprocess.CalledProcessError as e:
+            log.fatal("Failed to remove test instance  Error ({}) {}".format(e.returncode, e.output))
+
+    request.addfinalizer(fin)
+
+
 if __name__ == '__main__':
     # Run isolated
     # -s for DEBUG mode
