@@ -32,7 +32,7 @@ log = logging.getLogger(__name__)
 
 
 @pytest.fixture(scope="module")
-def test_user(topology_st, request):
+def create_user(topology_st, request):
     """User for binding operation"""
 
     log.info('Adding user {}'.format(TEST_USER_DN))
@@ -60,14 +60,14 @@ def test_user(topology_st, request):
 
 
 @pytest.fixture(scope="module")
-def password_policy(topology_st, test_user):
+def password_policy(topology_st, create_user):
     """Set up password policy for subtree and user"""
 
     log.info('Enable fine-grained policy')
     try:
         topology_st.standalone.modify_s(DN_CONFIG, [(ldap.MOD_REPLACE,
                                                      'nsslapd-pwpolicy-local',
-                                                     'on')])
+                                                     b'on')])
     except ldap.LDAPError as e:
         log.error('Failed to set fine-grained policy: error {}'.format(
             e.message['desc']))
@@ -88,7 +88,7 @@ def password_policy(topology_st, test_user):
     try:
         topology_st.standalone.modify_s(OU_PEOPLE, [(ldap.MOD_REPLACE,
                                                      'pwdpolicysubentry',
-                                                     PW_POLICY_CONT_PEOPLE)])
+                                                     ensure_bytes(PW_POLICY_CONT_PEOPLE))])
     except ldap.LDAPError as e:
         log.error('Failed to pwdpolicysubentry pw policy ' \
                   'policy for {}: error {}'.format(OU_PEOPLE,
@@ -110,7 +110,7 @@ def password_policy(topology_st, test_user):
     try:
         topology_st.standalone.modify_s(TEST_USER_DN, [(ldap.MOD_REPLACE,
                                                         'pwdpolicysubentry',
-                                                        PW_POLICY_CONT_USER)])
+                                                        ensure_bytes(PW_POLICY_CONT_USER))])
     except ldap.LDAPError as e:
         log.error('Failed to pwdpolicysubentry pw policy ' \
                   'policy for {}: error {}'.format(TEST_USER_DN,
@@ -122,24 +122,27 @@ def password_policy(topology_st, test_user):
                          [('on', 'off', ldap.UNWILLING_TO_PERFORM),
                           ('off', 'off', ldap.UNWILLING_TO_PERFORM),
                           ('off', 'on', None), ('on', 'on', None)])
-def test_change_pwd(topology_st, test_user, password_policy,
+def test_change_pwd(topology_st, create_user, password_policy,
                     subtree_pwchange, user_pwchange, exception):
     """Verify that 'passwordChange' attr works as expected
     User should have a priority over a subtree.
 
-    :feature: Password policy
-
-    :setup: Standalone instance, test user,
+    :id: 2c884432-2ba1-4662-8e5d-2cd49f77e5fa
+    :setup: Standalone instance, a test user,
             password policy entries for a user and a subtree
-
-    :steps: 1. Set passwordChange on the user and the subtree
-               to various combinations
-            2. Bind as test user
-            3. Try to change password
-
-    :expectedresults: Subtree/User passwordChange - result
-             off/on, on/on - success
-             on/off, off/off - UNWILLING_TO_PERFORM
+    :steps:
+        1. Set passwordChange on the user and the subtree
+           to various combinations
+        2. Bind as test user
+        3. Try to change password
+        4. Clean up - change the password to default while bound as DM
+    :expectedresults:
+        1. passwordChange should be successfully set
+        2. Bind should be successful
+        3. Subtree/User passwordChange - result, accordingly:
+           off/on, on/on - success;
+           on/off, off/off - UNWILLING_TO_PERFORM
+        4. Operation should be successful
     """
 
     log.info('Set passwordChange to "{}" - {}'.format(subtree_pwchange,
@@ -147,7 +150,7 @@ def test_change_pwd(topology_st, test_user, password_policy,
     try:
         topology_st.standalone.modify_s(PW_POLICY_CONT_PEOPLE, [(ldap.MOD_REPLACE,
                                                                  'passwordChange',
-                                                                 subtree_pwchange)])
+                                                                 ensure_bytes(subtree_pwchange))])
     except ldap.LDAPError as e:
         log.error('Failed to set passwordChange ' \
                   'policy for {}: error {}'.format(PW_POLICY_CONT_PEOPLE,
@@ -159,7 +162,7 @@ def test_change_pwd(topology_st, test_user, password_policy,
     try:
         topology_st.standalone.modify_s(PW_POLICY_CONT_USER, [(ldap.MOD_REPLACE,
                                                                'passwordChange',
-                                                               user_pwchange)])
+                                                               ensure_bytes(user_pwchange))])
     except ldap.LDAPError as e:
         log.error('Failed to set passwordChange ' \
                   'policy for {}: error {}'.format(PW_POLICY_CONT_USER,
@@ -174,11 +177,11 @@ def test_change_pwd(topology_st, test_user, password_policy,
             with pytest.raises(exception):
                 topology_st.standalone.modify_s(TEST_USER_DN, [(ldap.MOD_REPLACE,
                                                                 'userPassword',
-                                                                'new_pass')])
+                                                                b'new_pass')])
         else:
             topology_st.standalone.modify_s(TEST_USER_DN, [(ldap.MOD_REPLACE,
                                                             'userPassword',
-                                                            'new_pass')])
+                                                            b'new_pass')])
     except ldap.LDAPError as e:
         log.error('Failed to change userpassword for {}: error {}'.format(
             TEST_USER_DN, e.message['info']))
@@ -188,29 +191,35 @@ def test_change_pwd(topology_st, test_user, password_policy,
         topology_st.standalone.simple_bind_s(DN_DM, PASSWORD)
         topology_st.standalone.modify_s(TEST_USER_DN, [(ldap.MOD_REPLACE,
                                                         'userPassword',
-                                                        TEST_USER_PWD)])
+                                                        ensure_bytes(TEST_USER_PWD))])
 
 
-def test_pwd_min_age(topology_st, test_user, password_policy):
+def test_pwd_min_age(topology_st, create_user, password_policy):
     """If we set passwordMinAge to some value, for example to 10, then it
     should not allow the user to change the password within 10 seconds after
     his previous change.
 
-    :ID: 85b98516-8c82-45bd-b9ec-90bd1245e09c
-    :feature: Password policy
-    :setup: Standalone instance, test user,
+    :id: 85b98516-8c82-45bd-b9ec-90bd1245e09c
+    :setup: Standalone instance, a test user,
             password policy entries for a user and a subtree
-    :steps: 1. Set passwordMinAge to 10 on the user pwpolicy entry
-            2. Set passwordMinAge to 10 on the subtree pwpolicy entry
-            3. Set passwordMinAge to 10 on the cn=config entry
-            4. Bind as test user
-            5. Try to change password two times in a row
-            6. Wait 12 seconds
-            7. Try to change password
-    :expectedresults: User should be not allowed to change the password
-             right after previous change - CONSTRAINT_VIOLATION
-             User should be not allowed to change the password
-             after 12 seconds passed
+    :steps:
+        1. Set passwordMinAge to 10 on the user pwpolicy entry
+        2. Set passwordMinAge to 10 on the subtree pwpolicy entry
+        3. Set passwordMinAge to 10 on the cn=config entry
+        4. Bind as test user
+        5. Try to change the password two times in a row
+        6. Wait 12 seconds
+        7. Try to change the password
+        8. Clean up - change the password to default while bound as DM
+    :expectedresults:
+        1. passwordMinAge should be successfully set on the user pwpolicy entry
+        2. passwordMinAge should be successfully set on the subtree pwpolicy entry
+        3. passwordMinAge should be successfully set on the cn=config entry
+        4. Bind should be successful
+        5. The password should be successfully changed
+        6. 12 seconds have passed
+        7. Constraint Violation error should be raised
+        8. Operation should be successful
     """
 
     num_seconds = '10'
@@ -219,7 +228,7 @@ def test_pwd_min_age(topology_st, test_user, password_policy):
     try:
         topology_st.standalone.modify_s(PW_POLICY_CONT_PEOPLE, [(ldap.MOD_REPLACE,
                                                                  'passwordminage',
-                                                                 num_seconds)])
+                                                                 ensure_bytes(num_seconds))])
     except ldap.LDAPError as e:
         log.error('Failed to set passwordminage ' \
                   'policy for {}: error {}'.format(PW_POLICY_CONT_PEOPLE,
@@ -230,7 +239,7 @@ def test_pwd_min_age(topology_st, test_user, password_policy):
     try:
         topology_st.standalone.modify_s(PW_POLICY_CONT_USER, [(ldap.MOD_REPLACE,
                                                                'passwordminage',
-                                                               num_seconds)])
+                                                               ensure_bytes(num_seconds))])
     except ldap.LDAPError as e:
         log.error('Failed to set passwordminage ' \
                   'policy for {}: error {}'.format(PW_POLICY_CONT_USER,
@@ -241,7 +250,7 @@ def test_pwd_min_age(topology_st, test_user, password_policy):
     try:
         topology_st.standalone.modify_s(DN_CONFIG, [(ldap.MOD_REPLACE,
                                                      'passwordminage',
-                                                     num_seconds)])
+                                                     ensure_bytes(num_seconds))])
     except ldap.LDAPError as e:
         log.error('Failed to set passwordminage ' \
                   'policy for {}: error {}'.format(DN_CONFIG,
@@ -254,7 +263,7 @@ def test_pwd_min_age(topology_st, test_user, password_policy):
         topology_st.standalone.simple_bind_s(TEST_USER_DN, TEST_USER_PWD)
         topology_st.standalone.modify_s(TEST_USER_DN, [(ldap.MOD_REPLACE,
                                                         'userPassword',
-                                                        'new_pass')])
+                                                        b'new_pass')])
     except ldap.LDAPError as e:
         log.error('Failed to change userpassword for {}: error {}'.format(
             TEST_USER_DN, e.message['info']))
@@ -266,7 +275,7 @@ def test_pwd_min_age(topology_st, test_user, password_policy):
     with pytest.raises(ldap.CONSTRAINT_VIOLATION):
         topology_st.standalone.modify_s(TEST_USER_DN, [(ldap.MOD_REPLACE,
                                                         'userPassword',
-                                                        'new_new_pass')])
+                                                        b'new_new_pass')])
 
     log.info('Wait {} second'.format(int(num_seconds) + 2))
     time.sleep(int(num_seconds) + 2)
@@ -276,7 +285,7 @@ def test_pwd_min_age(topology_st, test_user, password_policy):
         topology_st.standalone.simple_bind_s(TEST_USER_DN, 'new_pass')
         topology_st.standalone.modify_s(TEST_USER_DN, [(ldap.MOD_REPLACE,
                                                         'userPassword',
-                                                        TEST_USER_PWD)])
+                                                        ensure_bytes(TEST_USER_PWD))])
     except ldap.LDAPError as e:
         log.error('Failed to change userpassword for {}: error {}'.format(
             TEST_USER_DN, e.message['info']))
@@ -286,7 +295,7 @@ def test_pwd_min_age(topology_st, test_user, password_policy):
         topology_st.standalone.simple_bind_s(DN_DM, PASSWORD)
         topology_st.standalone.modify_s(TEST_USER_DN, [(ldap.MOD_REPLACE,
                                                         'userPassword',
-                                                        TEST_USER_PWD)])
+                                                        ensure_bytes(TEST_USER_PWD))])
 
 
 if __name__ == '__main__':
