@@ -7,10 +7,13 @@
 #
 import pytest
 import time
-from lib389._constants import SUFFIX, PASSWORD, DN_DM
+from lib389._constants import SUFFIX, PASSWORD, DN_DM, DN_CONFIG, PLUGIN_RETRO_CHANGELOG, DEFAULT_SUFFIX, DEFAULT_CHANGELOG_DB
+from lib389 import Entry
 from lib389.idm.user import UserAccounts
 from lib389.utils import ldap, os, logging, ensure_bytes
 from lib389.topologies import topology_st as topo
+from lib389.topologies import topology_m1 as topo_master
+from lib389.idm.organizationalunit import OrganizationalUnits
 
 DEBUGGING = os.getenv("DEBUGGING", default=False)
 if DEBUGGING:
@@ -25,10 +28,10 @@ user_data = {'cn': 'CNpwtest1', 'sn': 'SNpwtest1', 'uid': 'UIDpwtest1', 'mail':
 TEST_PASSWORDS = list(user_data.values())
 # Add substring/token values of "CNpwtest1"
 TEST_PASSWORDS += ['CNpwtest1ZZZZ', 'ZZZZZCNpwtest1',
-                    'ZCNpwtest1', 'CNpwtest1Z', 'ZCNpwtest1Z',
-                    'ZZCNpwtest1', 'CNpwtest1ZZ', 'ZZCNpwtest1ZZ',
-                    'ZZZCNpwtest1', 'CNpwtest1ZZZ', 'ZZZCNpwtest1ZZZ',
-                    'ZZZZZZCNpwtest1ZZZZZZZZ']
+                   'ZCNpwtest1', 'CNpwtest1Z', 'ZCNpwtest1Z',
+                   'ZZCNpwtest1', 'CNpwtest1ZZ', 'ZZCNpwtest1ZZ',
+                   'ZZZCNpwtest1', 'CNpwtest1ZZZ', 'ZZZCNpwtest1ZZZ',
+                   'ZZZZZZCNpwtest1ZZZZZZZZ']
 
 TEST_PASSWORDS2 = (
     'CN12pwtest31', 'SN3pwtest231', 'UID1pwtest123', 'MAIL2pwtest12@redhat.com', '2GN1pwtest123', 'People123')
@@ -45,13 +48,14 @@ def passw_policy(topo, request):
     topo.standalone.config.set('nsslapd-pwpolicy-local', 'on')
 
     subtree = 'ou=people,{}'.format(SUFFIX)
+    print(subtree)
     log.info('Configure subtree password policy for {}'.format(subtree))
-    topo.standalone.subtreePwdPolicy(subtree, {'passwordchange': ensure_bytes('on'),
-                                               'passwordCheckSyntax': ensure_bytes('on'),
-                                               'passwordLockout': ensure_bytes('on'),
-                                               'passwordResetFailureCount': ensure_bytes('3'),
-                                               'passwordLockoutDuration': ensure_bytes('3'),
-                                               'passwordMaxFailure': ensure_bytes('2')})
+    topo.standalone.subtreePwdPolicy(subtree, {'passwordchange': b'on',
+                                               'passwordCheckSyntax': b'on',
+                                               'passwordLockout': b'on',
+                                               'passwordResetFailureCount': b'3',
+                                               'passwordLockoutDuration': b'3',
+                                               'passwordMaxFailure': b'2'})
     time.sleep(1)
 
     def fin():
@@ -64,7 +68,7 @@ def passw_policy(topo, request):
 
 
 @pytest.fixture(scope="module")
-def test_user(topo, request):
+def create_user(topo, request):
     """Add test users using UserAccounts"""
 
     log.info('Adding user-uid={},ou=people,{}'.format(user_data['uid'], SUFFIX))
@@ -85,7 +89,7 @@ def test_user(topo, request):
     return tuser
 
 
-def test_pwp_local_unlock(topo, passw_policy, test_user):
+def test_pwp_local_unlock(topo, passw_policy, create_user):
     """Test subtree policies use the same global default for passwordUnlock
 
     :id: 741a8417-5f65-4012-b9ed-87987ce3ca1b
@@ -101,12 +105,12 @@ def test_pwp_local_unlock(topo, passw_policy, test_user):
     """
 
     log.info("Verify user can bind...")
-    test_user.bind(PASSWORD)
+    create_user.bind(PASSWORD)
 
     log.info('Test passwordUnlock default - user should be able to reset password after lockout')
-    for i in range(0,2):
+    for i in range(0, 2):
         try:
-            test_user.bind("bad-password")
+            create_user.bind("bad-password")
         except ldap.INVALID_CREDENTIALS:
             # expected
             pass
@@ -114,79 +118,78 @@ def test_pwp_local_unlock(topo, passw_policy, test_user):
             log.fatal("Got unexpected failure: " + atr(e))
             raise e
 
-
     log.info('Verify account is locked')
     with pytest.raises(ldap.CONSTRAINT_VIOLATION):
-        test_user.bind(PASSWORD)
+        create_user.bind(PASSWORD)
 
     log.info('Wait for lockout duration...')
     time.sleep(4)
 
     log.info('Check if user can now bind with correct password')
-    test_user.bind(PASSWORD)
+    create_user.bind(PASSWORD)
 
 
 @pytest.mark.bz1465600
 @pytest.mark.parametrize("user_pasw", TEST_PASSWORDS)
-def test_trivial_passw_check(topo, passw_policy, test_user, user_pasw):
+def test_trivial_passw_check(topo, passw_policy, create_user, user_pasw):
     """PasswordCheckSyntax attribute fails to validate cn, sn, uid, givenname, ou and mail attributes
 
     :id: bf9fe1ef-56cb-46a3-a6f8-5530398a06dc
-    :feature: Password policy
     :setup: Standalone instance.
-    :steps: 1. Configure local password policy with PasswordCheckSyntax set to on.
-            2. Add users with cn, sn, uid, givenname, mail and userPassword attributes.
-            3. Configure subtree password policy for ou=people subtree.
-            4. Reset userPassword with trivial values like cn, sn, uid, givenname, ou and mail attributes.
+    :steps:
+        1. Configure local password policy with PasswordCheckSyntax set to on.
+        2. Add users with cn, sn, uid, givenname, mail and userPassword attributes.
+        3. Configure subtree password policy for ou=people subtree.
+        4. Reset userPassword with trivial values like cn, sn, uid, givenname, ou and mail attributes.
     :expectedresults:
-            1. Enabling PasswordCheckSyntax should PASS.
-            2. Add users should PASS.
-            3. Configure subtree password policy should PASS.
-            4. Resetting userPassword to cn, sn, uid and mail should be rejected.
+        1. Enabling PasswordCheckSyntax should PASS.
+        2. Add users should PASS.
+        3. Configure subtree password policy should PASS.
+        4. Resetting userPassword to cn, sn, uid and mail should be rejected.
     """
 
-    conn = test_user.bind(PASSWORD)
+    conn = create_user.bind(PASSWORD)
     try:
         log.info('Replace userPassword attribute with {}'.format(user_pasw))
         with pytest.raises(ldap.CONSTRAINT_VIOLATION) as excinfo:
-            conn.modify_s(test_user.dn, [(ldap.MOD_REPLACE, 'userPassword', user_pasw)])
+            conn.modify_s(create_user.dn, [(ldap.MOD_REPLACE, 'userPassword', ensure_bytes(user_pasw))])
             log.fatal('Failed: Userpassword with {} is accepted'.format(user_pasw))
         assert 'password based off of user entry' in str(excinfo.value)
     finally:
         conn.unbind_s()
-        test_user.set('userPassword', PASSWORD)
+        create_user.set('userPassword', PASSWORD)
 
 
 @pytest.mark.parametrize("user_pasw", TEST_PASSWORDS)
-def test_global_vs_local(topo, passw_policy, test_user, user_pasw):
+def test_global_vs_local(topo, passw_policy, create_user, user_pasw):
     """Passwords rejected if its similar to uid, cn, sn, givenname, ou and mail attributes
 
     :id: dfd6cf5d-8bcd-4895-a691-a43ad9ec1be8
-    :feature: Password policy
     :setup: Standalone instance
-    :steps: 1. Configure global password policy with PasswordCheckSyntax set to off
-            2. Add users with cn, sn, uid, mail, givenname and userPassword attributes
-            3. Replace userPassword similar to cn, sn, uid, givenname, ou and mail attributes
+    :steps:
+        1. Configure global password policy with PasswordCheckSyntax set to off
+        2. Add users with cn, sn, uid, mail, givenname and userPassword attributes
+        3. Replace userPassword similar to cn, sn, uid, givenname, ou and mail attributes
     :expectedresults:
-            1. Disabling the local policy should PASS.
-            2. Add users should PASS.
-            3. Resetting userPasswords similar to cn, sn, uid, givenname, ou and mail attributes should PASS.
+        1. Disabling the local policy should PASS.
+        2. Add users should PASS.
+        3. Resetting userPasswords similar to cn, sn, uid, givenname, ou and mail attributes should PASS.
     """
 
     log.info('Configure Pwpolicy with PasswordCheckSyntax and nsslapd-pwpolicy-local set to off')
     topo.standalone.config.set('nsslapd-pwpolicy-local', 'off')
 
-    conn = test_user.bind(PASSWORD)
+    conn = create_user.bind(PASSWORD)
     log.info('Replace userPassword attribute with {}'.format(user_pasw))
     try:
         try:
-            conn.modify_s(test_user.dn, [(ldap.MOD_REPLACE, 'userPassword', user_pasw)])
+            conn.modify_s(create_user.dn, [(ldap.MOD_REPLACE, 'userPassword', ensure_bytes(user_pasw))])
         except ldap.LDAPError as e:
             log.fatal('Failed to replace userPassword: error {}'.format(e.message['desc']))
             raise e
     finally:
         conn.unbind_s()
-        test_user.set('userPassword', PASSWORD)
+        create_user.set('userPassword', PASSWORD)
 
 
 if __name__ == '__main__':
