@@ -14,6 +14,7 @@ import pytest
 from lib389 import Entry
 from lib389._constants import *
 from lib389.topologies import topology_st
+from lib389.utils import *
 
 log = logging.getLogger(__name__)
 
@@ -44,7 +45,7 @@ def check_attr_val(topology_st, dn, attr, expected):
             log.fatal('Failed to get %s' % dn)
             assert False
     except ldap.LDAPError as e:
-        log.fatal('Failed to search ' + dn + ': ' + e.message['desc'])
+        log.fatal('Failed to search ' + dn + ': ' + e.args[0]['desc'])
         assert False
 
 
@@ -92,15 +93,15 @@ def test_48294_init(topology_st):
 
     log.info('Enable Dynamic plugins, and the linked Attrs plugin')
     try:
-        topology_st.standalone.modify_s(DN_CONFIG, [(ldap.MOD_REPLACE, 'nsslapd-dynamic-plugins', 'on')])
+        topology_st.standalone.modify_s(DN_CONFIG, [(ldap.MOD_REPLACE, 'nsslapd-dynamic-plugins', b'on')])
     except ldap.LDAPError as e:
-        log.fatal('Failed to enable dynamic plugin!' + e.message['desc'])
+        log.fatal('Failed to enable dynamic plugin!' + e.args[0]['desc'])
         assert False
 
     try:
         topology_st.standalone.plugins.enable(name=PLUGIN_LINKED_ATTRS)
     except ValueError as e:
-        log.fatal('Failed to enable linked attributes plugin!' + e.message['desc'])
+        log.fatal('Failed to enable linked attributes plugin!' + e.args[0]['desc'])
         assert False
 
     log.info('Add the plugin config entry')
@@ -112,7 +113,7 @@ def test_48294_init(topology_st):
             'managedType': MANAGEDTYPE
         })))
     except ldap.LDAPError as e:
-        log.fatal('Failed to add linked attr config entry: error ' + e.message['desc'])
+        log.fatal('Failed to add linked attr config entry: error ' + e.args[0]['desc'])
         assert False
 
     log.info('Add 2 entries: manager1 and employee1')
@@ -121,7 +122,7 @@ def test_48294_init(topology_st):
             'objectclass': 'top extensibleObject'.split(),
             'uid': 'manager1'})))
     except ldap.LDAPError as e:
-        log.fatal('Add manager1 failed: error ' + e.message['desc'])
+        log.fatal('Add manager1 failed: error ' + e.args[0]['desc'])
         assert False
 
     try:
@@ -129,15 +130,15 @@ def test_48294_init(topology_st):
             'objectclass': 'top extensibleObject'.split(),
             'uid': 'employee1'})))
     except ldap.LDAPError as e:
-        log.fatal('Add employee1 failed: error ' + e.message['desc'])
+        log.fatal('Add employee1 failed: error ' + e.args[0]['desc'])
         assert False
 
     log.info('Add linktype to manager1')
     topology_st.standalone.modify_s('uid=manager1,%s' % OU_PEOPLE,
-                                    [(ldap.MOD_ADD, LINKTYPE, 'uid=employee1,%s' % OU_PEOPLE)])
+                                    [(ldap.MOD_ADD, LINKTYPE, ensure_bytes('uid=employee1,%s' % OU_PEOPLE))])
 
     log.info('Check managed attribute')
-    check_attr_val(topology_st, 'uid=employee1,%s' % OU_PEOPLE, MANAGEDTYPE, 'uid=manager1,%s' % OU_PEOPLE)
+    check_attr_val(topology_st, 'uid=employee1,%s' % OU_PEOPLE, MANAGEDTYPE, ensure_bytes('uid=manager1,%s' % OU_PEOPLE))
 
     log.info('PASSED')
 
@@ -154,13 +155,13 @@ def test_48294_run_0(topology_st):
     log.info('Modify the value of directReport to uid=employee2')
     try:
         topology_st.standalone.modify_s('uid=manager1,%s' % OU_PEOPLE,
-                                        [(ldap.MOD_REPLACE, LINKTYPE, 'uid=employee2,%s' % OU_PEOPLE)])
+                                        [(ldap.MOD_REPLACE, LINKTYPE, ensure_bytes('uid=employee2,%s' % OU_PEOPLE))])
     except ldap.LDAPError as e:
-        log.fatal('Failed to replace uid=employee1 with employee2: ' + e.message['desc'])
+        log.fatal('Failed to replace uid=employee1 with employee2: ' + e.args[0]['desc'])
         assert False
 
     log.info('Check managed attribute')
-    check_attr_val(topology_st, 'uid=employee2,%s' % OU_PEOPLE, MANAGEDTYPE, 'uid=manager1,%s' % OU_PEOPLE)
+    check_attr_val(topology_st, 'uid=employee2,%s' % OU_PEOPLE, MANAGEDTYPE, ensure_bytes('uid=manager1,%s' % OU_PEOPLE))
 
     log.info('PASSED')
 
@@ -177,20 +178,20 @@ def test_48294_run_1(topology_st):
     log.info('Modify the value of directReport to uid=employee3')
     try:
         topology_st.standalone.modify_s('uid=manager1,%s' % OU_PEOPLE,
-                                        [(ldap.MOD_DELETE, LINKTYPE, 'uid=employee2,%s' % OU_PEOPLE)])
+                                        [(ldap.MOD_DELETE, LINKTYPE, ensure_bytes('uid=employee2,%s' % OU_PEOPLE))])
     except ldap.LDAPError as e:
-        log.fatal('Failed to delete employee2: ' + e.message['desc'])
+        log.fatal('Failed to delete employee2: ' + e.args[0]['desc'])
         assert False
 
     try:
         topology_st.standalone.modify_s('uid=manager1,%s' % OU_PEOPLE,
-                                        [(ldap.MOD_ADD, LINKTYPE, 'uid=employee3,%s' % OU_PEOPLE)])
+                                        [(ldap.MOD_ADD, LINKTYPE, ensure_bytes('uid=employee3,%s' % OU_PEOPLE))])
     except ldap.LDAPError as e:
-        log.fatal('Failed to add employee3: ' + e.message['desc'])
+        log.fatal('Failed to add employee3: ' + e.args[0]['desc'])
         assert False
 
     log.info('Check managed attribute')
-    check_attr_val(topology_st, 'uid=employee3,%s' % OU_PEOPLE, MANAGEDTYPE, 'uid=manager1,%s' % OU_PEOPLE)
+    check_attr_val(topology_st, 'uid=employee3,%s' % OU_PEOPLE, MANAGEDTYPE, ensure_bytes('uid=manager1,%s' % OU_PEOPLE))
 
     log.info('PASSED')
 
@@ -205,7 +206,7 @@ def test_48294_run_2(topology_st):
     _modrdn_entry(topology_st, entry_dn='uid=manager1,%s' % OU_PEOPLE, new_rdn='uid=manager2')
 
     log.info('Check managed attribute')
-    check_attr_val(topology_st, 'uid=employee3,%s' % OU_PEOPLE, MANAGEDTYPE, 'uid=manager2,%s' % OU_PEOPLE)
+    check_attr_val(topology_st, 'uid=employee3,%s' % OU_PEOPLE, MANAGEDTYPE, ensure_bytes('uid=manager2,%s' % OU_PEOPLE))
 
     log.info('PASSED')
 
