@@ -524,6 +524,10 @@ connection_dispatch_operation(Connection *conn, Operation *op, Slapi_PBlock *pb)
     int enable_nagle = config_get_nagle();
     int pop_cork = 0;
 #endif
+
+    /* Set the connid and op_id to be used by internal op logging */
+    slapi_td_reset_internal_logging(conn->c_connid, op->o_opid);
+
     /* Get the effective key length now since the first SSL handshake should be complete */
     connection_set_ssl_ssf(conn);
 
@@ -741,14 +745,18 @@ connection_acquire_nolock(Connection *conn)
 
 /* returns non-0 if connection can be reused and 0 otherwise */
 int
-connection_is_free(Connection *conn)
+connection_is_free(Connection *conn, int use_lock)
 {
     int rc;
 
-    PR_EnterMonitor(conn->c_mutex);
+    if (use_lock) {
+        PR_EnterMonitor(conn->c_mutex);
+    }
     rc = conn->c_sd == SLAPD_INVALID_SOCKET && conn->c_refcnt == 0 &&
          !(conn->c_flags & CONN_FLAG_CLOSING);
-    PR_ExitMonitor(conn->c_mutex);
+    if (use_lock) {
+        PR_ExitMonitor(conn->c_mutex);
+    }
 
     return rc;
 }
@@ -1716,7 +1724,9 @@ connection_threadmain()
         if ((tag != LDAP_REQ_UNBIND) && !thread_turbo_flag && !replication_connection) {
             if (!more_data) {
                 conn->c_flags &= ~CONN_FLAG_MAX_THREADS;
+                PR_EnterMonitor(conn->c_mutex);
                 connection_make_readable_nolock(conn);
+                PR_ExitMonitor(conn->c_mutex);
                 /* once the connection is readable, another thread may access conn,
                  * so need locking from here on */
                 signal_listner();
@@ -1805,9 +1815,17 @@ connection_threadmain()
         slapi_counter_increment(ops_completed);
         /* If this op isn't a persistent search, remove it */
         if (op->o_flags & OP_FLAG_PS) {
-            PR_EnterMonitor(conn->c_mutex);
-            connection_release_nolock(conn); /* psearch acquires ref to conn - release this one now */
-            PR_ExitMonitor(conn->c_mutex);
+            /* Release the connection (i.e. decrease refcnt) at the condition
+             * this thread will not loop on it.
+             * If we are in turbo mode (dedicated to that connection) or
+             * more_data (continue reading buffered req) this thread
+             * continues to hold the connection
+             */
+            if (!thread_turbo_flag && !more_data) {
+                PR_EnterMonitor(conn->c_mutex);
+                connection_release_nolock(conn); /* psearch acquires ref to conn - release this one now */
+                PR_ExitMonitor(conn->c_mutex);
+            }
             /* ps_add makes a shallow copy of the pb - so we
                  * can't free it or init it here - just set operation to NULL.
                  * ps_send_results will call connection_remove_operation_ext to free it
@@ -1822,9 +1840,17 @@ connection_threadmain()
 
             /* If we're in turbo mode, we keep our reference to the connection alive */
             /* can't use the more_data var because connection could have changed in another thread */
-            more_data = conn_buffered_data_avail_nolock(conn, &conn_closed) ? 1 : 0;
-            slapi_log_err(SLAPI_LOG_CONNS, "connection_threadmain", "conn %" PRIu64 " check more_data %d thread_turbo_flag %d\n",
-                          conn->c_connid, more_data, thread_turbo_flag);
+            slapi_log_err(SLAPI_LOG_CONNS, "connection_threadmain", "conn %" PRIu64 " check more_data %d thread_turbo_flag %d"
+                          "repl_conn_bef %d, repl_conn_now %d\n",
+                          conn->c_connid, more_data, thread_turbo_flag,
+                          replication_connection, conn->c_isreplication_session);
+            if (!replication_connection &&  conn->c_isreplication_session) {
+                /* it a connection that was just flagged as replication connection */
+                more_data = 0;
+            } else {
+                /* normal connection or already established replication connection */
+                more_data = conn_buffered_data_avail_nolock(conn, &conn_closed) ? 1 : 0;
+            }
             if (!more_data) {
                 if (!thread_turbo_flag) {
                     /*
@@ -1889,7 +1915,7 @@ connection_activity(Connection *conn, int maxthreads)
         slapi_counter_increment(max_threads_count);
         slapi_counter_increment(conns_in_maxthreads);
         slapi_counter_increment(g_get_global_snmp_vars()->ops_tbl.dsConnectionsInMaxThreads);
-        slapi_counter_increment(g_get_global_snmp_vars()->ops_tbl.dsMaxThreadsHit);
+        slapi_counter_increment(g_get_global_snmp_vars()->ops_tbl.dsMaxThreadsHits);
     }
     op_stack_obj = connection_get_operation();
     connection_add_operation(conn, op_stack_obj->op);
