@@ -14,7 +14,6 @@
 /* opshared.c - functions shared between regular and internal operations */
 
 #include "slap.h"
-#include "index_subsys.h"
 
 #define PAGEDRESULTS_PAGE_END 1
 #define PAGEDRESULTS_SEARCH_END 2
@@ -295,15 +294,16 @@ op_shared_search(Slapi_PBlock *pb, int send_result)
         uint64_t connid;
         int32_t op_id;
         int32_t op_internal_id;
+        int32_t op_nested_count;
 
 #define SLAPD_SEARCH_FMTSTR_BASE "conn=%" PRIu64 " op=%d SRCH base=\"%s\" scope=%d "
-#define SLAPD_SEARCH_FMTSTR_BASE_INT_INT "conn=Internal(%" PRIu64 ") op=%d(%d) SRCH base=\"%s\" scope=%d "
-#define SLAPD_SEARCH_FMTSTR_BASE_EXT_INT "conn=%" PRIu64 " (Internal) op=%d(%d) SRCH base=\"%s\" scope=%d "
+#define SLAPD_SEARCH_FMTSTR_BASE_INT_INT "conn=Internal(%" PRIu64 ") op=%d(%d)(%d) SRCH base=\"%s\" scope=%d "
+#define SLAPD_SEARCH_FMTSTR_BASE_EXT_INT "conn=%" PRIu64 " (Internal) op=%d(%d)(%d) SRCH base=\"%s\" scope=%d "
 #define SLAPD_SEARCH_FMTSTR_REMAINDER " attrs=%s%s%s\n"
 
         PR_ASSERT(fstr);
         if (internal_op) {
-            get_internal_conn_op(&connid, &op_id, &op_internal_id);
+            get_internal_conn_op(&connid, &op_id, &op_internal_id, &op_nested_count);
         }
         if (strlen(fstr) > 1024) {
             /*
@@ -357,6 +357,7 @@ op_shared_search(Slapi_PBlock *pb, int send_result)
                              connid,
                              op_id,
                              op_internal_id,
+                             op_nested_count,
                              normbase,
                              scope, fstr, attrliststr,
                              flag_psearch ? " options=persistent" : "",
@@ -607,9 +608,6 @@ op_shared_search(Slapi_PBlock *pb, int send_result)
         }
     }
 
-    /* PAR: now filters have been rewritten, we can assign plugins to work on them */
-    index_subsys_assign_filter_decoders(pb);
-
     nentries = 0;
     rc = -1; /* zero backends would mean failure */
     while (be) {
@@ -988,7 +986,6 @@ free_and_return:
 
 free_and_return_nolock:
     slapi_pblock_set(pb, SLAPI_PLUGIN_OPRETURN, &rc);
-    index_subsys_filter_decoders_done(pb);
 
     if (free_sdn) {
         slapi_pblock_get(pb, SLAPI_SEARCH_TARGET_SDN, &sdn);
