@@ -299,6 +299,16 @@ int config_set_pwpolicy_local(const char *attrname, char *value, char *errorbuf,
 int config_set_allow_hashed_pw(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_pwpolicy_inherit_global(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_pw_syntax(const char *attrname, char *value, char *errorbuf, int apply);
+
+int32_t config_set_pw_palindrome(const char *attrname, char *value, char *errorbuf, int apply);
+int32_t config_set_pw_dict_check(const char *attrname, char *value, char *errorbuf, int apply);
+int32_t config_set_pw_dict_path(const char *attrname, char *value, char *errorbuf, int apply);
+int32_t config_set_pw_user_attrs(const char *attrname, char *value, char *errorbuf, int apply);
+int32_t config_set_pw_bad_words(const char *attrname, char *value, char *errorbuf, int apply);
+int32_t config_set_pw_max_seq_sets(const char *attrname, char *value, char *errorbuf, int apply);
+int32_t config_set_pw_max_seq(const char *attrname, char *value, char *errorbuf, int apply);
+int32_t config_set_pw_max_class_repeats(const char *attrname, char *value, char *errorbuf, int apply);
+
 int config_set_pw_minlength(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_pw_mindigits(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_pw_minalphas(const char *attrname, char *value, char *errorbuf, int apply);
@@ -491,7 +501,7 @@ char *config_get_referral_mode(void);
 int config_get_conntablesize(void);
 int config_check_referral_mode(void);
 ber_len_t config_get_maxbersize(void);
-size_t config_get_maxsasliosize(void);
+int32_t config_get_maxsasliosize(void);
 char *config_get_versionstring(void);
 char *config_get_buildnum(void);
 int config_get_enquote_sup_oc(void);
@@ -952,6 +962,7 @@ int plugin_call_mmr_plugin_postop ( Slapi_PBlock *pb, Slapi_Entry *e, int flags)
  * pw_mgmt.c
  */
 void pw_init(void);
+void check_must_change_pw(Slapi_PBlock *pb, Slapi_Entry *e);
 int need_new_pw(Slapi_PBlock *pb, Slapi_Entry *e, int pwresponse_req);
 int update_pw_info(Slapi_PBlock *pb, char *old_pw);
 int check_pw_syntax(Slapi_PBlock *pb, const Slapi_DN *sdn, Slapi_Value **vals, char **old_pw, Slapi_Entry *e, int mod_op);
@@ -1431,7 +1442,7 @@ int connection_acquire_nolock(Connection *conn);
 int connection_acquire_nolock_ext(Connection *conn, int allow_when_closing);
 int connection_release_nolock(Connection *conn);
 int connection_release_nolock_ext(Connection *conn, int release_only);
-int connection_is_free(Connection *conn);
+int connection_is_free(Connection *conn, int user_lock);
 int connection_is_active_nolock(Connection *conn);
 #if defined(USE_OPENLDAP)
 ber_slen_t openldap_read_function(Sockbuf_IO_Desc *sbiod, void *buf, ber_len_t len);
