@@ -1591,16 +1591,36 @@ slapi_create_errormsg(
 }
 
 void
-get_internal_conn_op (uint64_t *connid, int32_t *op_id, int32_t *op_internal_id) {
+get_internal_conn_op (uint64_t *connid, int32_t *op_id, int32_t *op_internal_id, int32_t *op_nested_count) {
     struct slapi_td_log_op_state_t *op_state = slapi_td_get_log_op_state();
 
     if (op_state != NULL) {
         *connid = op_state->conn_id;
         *op_id = op_state->op_id;
         *op_internal_id = op_state->op_int_id;
+        *op_nested_count = op_state->op_nest_count;
+
     } else {
         *connid = 0;
         *op_id = 0;
         *op_internal_id = 0;
+        *op_nested_count = 0;
     }
 }
+
+/*
+ * Extract a single value from an entry (as a string) -- if it's not in the
+ * entry, the default will be returned (which can be NULL).  You do not need
+ * to free the returned string value.
+ */
+const char *
+slapi_fetch_attr(Slapi_Entry *e, const char *attrname, char *default_val)
+{
+    Slapi_Attr *attr;
+    Slapi_Value *val = NULL;
+
+    if (slapi_entry_attr_find(e, attrname, &attr) != 0)
+        return default_val;
+    slapi_attr_first_value(attr, &val);
+    return slapi_value_get_string(val);
+}
