@@ -1,5 +1,6 @@
 # --- BEGIN COPYRIGHT BLOCK ---
 # Copyright (C) 2016 Red Hat, Inc.
+# Copyright (C) 2019 William Brown <william@blackhats.net.au>
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
@@ -269,7 +270,14 @@ class DSLdapObject(DSLogging):
         :param *args: tuples of key,value to replace.
         :type *args: (str, str)
         """
-        mods = list(map(lambda t: (ldap.MOD_REPLACE, ensure_str(t[0]), ensure_bytes(t[1])), args))
+
+        mods = []
+        for arg in args:
+            if isinstance(arg[1], list):
+                value = ensure_list_bytes(arg[1])
+            else:
+                value = [ensure_bytes(arg[1])]
+            mods.append((ldap.MOD_REPLACE, ensure_str(arg[0]), value))
         return self._instance.modify_ext_s(self._dn, mods, serverctrls=self._server_controls, clientctrls=self._client_controls)
 
     # This needs to work on key + val, and key
@@ -312,6 +320,18 @@ class DSLdapObject(DSLogging):
         if not self.present(attr, value):
             self.add(attr, value)
 
+    def ensure_removed(self, attr, value):
+        """Ensure that a attribute and value has been removed and not present
+        or remove it.
+
+        :param key: an attribute name
+        :type key: str
+        :param value: an attribute value
+        :type value: str
+        """
+        if self.present(attr, value):
+            self.remove(attr, value)
+
     # maybe this could be renamed?
     def set(self, key, value, action=ldap.MOD_REPLACE):
         """Perform a specified action on a key with value
@@ -358,7 +378,7 @@ class DSLdapObject(DSLogging):
     def apply_mods(self, mods):
         """Perform modification operation using several mods at once
 
-        :param mods: [(action, key, value),]
+        :param mods: [(action, key, value),] or [(ldap.MOD_DELETE, key),]
         :type mods: list of tuples
         :raises: ValueError - if a provided mod op is invalid
         """
@@ -368,25 +388,25 @@ class DSLdapObject(DSLogging):
             if len(mod) < 2:
                 # Error
                 raise ValueError('Not enough arguments in the mod op')
-            elif len(mod) == 2:  # no action
-                action = ldap.MOD_REPLACE
-                key, value = mod
+            elif len(mod) == 2:  # delete all attributes action
+                action, key = mod
+                if action != ldap.MOD_DELETE:
+                    raise ValueError('Not enough arguments in the mod op')
+                mod_list.append((action, key, None))
             elif len(mod) == 3:
                 action, key, value = mod
                 if action != ldap.MOD_REPLACE and \
                    action != ldap.MOD_ADD and \
                    action != ldap.MOD_DELETE:
                     raise ValueError('Invalid mod action(%s)' % str(action))
+                if isinstance(value, list):
+                    value = ensure_list_bytes(value)
+                else:
+                    value = [ensure_bytes(value)]
+                mod_list.append((action, key, value))
             else:
                 # Error too many items
                 raise ValueError('Too many arguments in the mod op')
-
-            if isinstance(value, list):
-                value = ensure_list_bytes(value)
-            else:
-                value = [ensure_bytes(value)]
-
-            mod_list.append((action, key, value))
         return self._instance.modify_ext_s(self._dn, mod_list, serverctrls=self._server_controls, clientctrls=self._client_controls)
 
     @classmethod
@@ -742,8 +762,8 @@ class DSLdapObject(DSLogging):
             self._dn = dn
             # Now use replace_many to setup our values
             mods = []
-            for k,v in valid_props.items():
-                mods.append( (ldap.MOD_REPLACE, k, v))
+            for k, v in list(valid_props.items()):
+                mods.append((ldap.MOD_REPLACE, k, v))
             self._instance.modify_ext_s(self._dn, mods, serverctrls=self._server_controls, clientctrls=self._client_controls)
         elif exists and not ensure:
             # raise "already exists."
