@@ -16,8 +16,16 @@ MUST_ATTRIBUTES = [
 RDN = 'cn'
 
 class PosixGroup(DSLdapObject):
-    def __init__(self, instance, dn=None, batch=False):
-        super(PosixGroup, self).__init__(instance, dn, batch)
+    """A single instance of PosixGroup entry
+
+    :param instance: An instance
+    :type instance: lib389.DirSrv
+    :param dn: Entry DN
+    :type dn: str
+    """
+
+    def __init__(self, instance, dn=None):
+        super(PosixGroup, self).__init__(instance, dn)
         self._rdn_attribute = RDN
         # Can I generate these from schema?
         self._must_attributes = MUST_ATTRIBUTES
@@ -31,16 +39,37 @@ class PosixGroup(DSLdapObject):
         self._protected = False
 
     def check_member(self, dn):
+        """Check if DN is a member
+
+        :param dn: Entry DN
+        :type dn: str
+        """
+
         return dn in self.get_attr_vals('member')
 
     def add_member(self, dn):
+        """Add DN as a member
+
+        :param dn: Entry DN
+        :type dn: str
+        """
+
         # Assert the DN exists?
         self.add('member', dn)
 
 
 class PosixGroups(DSLdapObjects):
-    def __init__(self, instance, basedn, batch=False, rdn='ou=Groups'):
-        super(PosixGroups, self).__init__(instance, batch)
+    """DSLdapObjects that represents PosixGroups entry
+    By default it uses 'ou=Groups' as rdn.
+
+    :param instance: An instance
+    :type instance: lib389.DirSrv
+    :param basedn: Base DN for all group entries below
+    :type basedn: str
+    """
+
+    def __init__(self, instance, basedn, rdn='ou=Groups'):
+        super(PosixGroups, self).__init__(instance)
         self._objectclasses = [
             'groupOfNames',
             'posixGroup',
