@@ -9,9 +9,10 @@
 import os
 import shutil
 import subprocess
+from lib389.utils import selinux_label_port
 
 
-def remove_ds_instance(dirsrv):
+def remove_ds_instance(dirsrv, force=False):
     """
     This will delete the instance as it is define. This must be a local instance.
     """
@@ -36,8 +37,11 @@ def remove_ds_instance(dirsrv):
     remove_paths['log_dir'] = dirsrv.ds_paths.log_dir
     # remove_paths['run_dir'] = dirsrv.ds_paths.run_dir
     remove_paths['tmpfiles_d'] = dirsrv.ds_paths.tmpfiles_d + "/dirsrv-" + dirsrv.serverid + ".conf"
+    remove_paths['inst_dir'] = dirsrv.ds_paths.inst_dir
 
     marker_path = "%s/sysconfig/dirsrv-%s" % (dirsrv.ds_paths.sysconf_dir, dirsrv.serverid)
+    etc_dirsrv_path = os.path.join(dirsrv.ds_paths.sysconf_dir, 'dirsrv/')
+    ssca_path = os.path.join(etc_dirsrv_path, 'ssca/')
 
     # Check the marker exists. If it *does not* warn about this, and say that to
     # force removal you should touch this file.
@@ -65,8 +69,9 @@ def remove_ds_instance(dirsrv):
     for path_k in remove_paths:
         _log.debug("Removing %s" % remove_paths[path_k])
         shutil.rmtree(remove_paths[path_k], ignore_errors=True)
+
     # Remove parent (/var/lib/dirsrv/slapd-INST)
-    shutil.rmtree(remove_paths['db_dir'].replace('db', ''))
+    shutil.rmtree(remove_paths['db_dir'].replace('db', ''), ignore_errors=True)
 
     # Finally remove the sysconfig marker.
     os.remove(marker_path)
@@ -76,6 +81,29 @@ def remove_ds_instance(dirsrv):
     _log.debug("Removing the systemd symlink")
     subprocess.check_call(["systemctl", "disable", "dirsrv@{}".format(dirsrv.serverid)])
 
+    # Remove selinux port label
+    _log.debug("Removing the port label")
+    try:
+        selinux_label_port(dirsrv.port, remove_label=True)
+    except ValueError as e:
+        if force:
+            pass
+        else:
+            _log.error(str(e))
+            raise e
+
+    if dirsrv.sslport is not None:
+        selinux_label_port(dirsrv.sslport, remove_label=True)
+
+    # If this was the last instance, remove the ssca directory
+    insts = dirsrv.list(all=True)
+    if len(insts) == 0:
+        # Remove /etc/dirsrv/ssca
+        try:
+            shutil.rmtree(ssca_path)
+        except FileNotFoundError:
+            pass
+
     # Done!
     _log.debug("Complete")
 
