@@ -1,5 +1,6 @@
 # --- BEGIN COPYRIGHT BLOCK ---
 # Copyright (C) 2016 Red Hat, Inc.
+# Copyright (C) 2019 William Brown <william@blackhats.net.au>
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
@@ -16,20 +17,24 @@ import socket
 import subprocess
 import getpass
 import configparser
-from lib389 import _ds_shutil_copytree
+from lib389 import _ds_shutil_copytree, DirSrv
 from lib389._constants import *
 from lib389.properties import *
 from lib389.passwd import password_hash, password_generate
 from lib389.nss_ssl import NssSsl
 from lib389.configurations import get_config
+from lib389.configurations.sample import create_base_domain
 from lib389.instance.options import General2Base, Slapd2Base, Backend2Base
 from lib389.paths import Paths
 from lib389.saslmap import SaslMappings
+from lib389.instance.remove import remove_ds_instance
 from lib389.utils import (
     assert_c,
     is_a_dn,
     ensure_str,
-    socket_check_open,)
+    socket_check_open,
+    selinux_label_port,
+    selinux_restorecon)
 
 ds_paths = Paths()
 
@@ -38,9 +43,9 @@ def get_port(port, default_port, secure=False):
     # Get the port number for the interactive installer and validate it
     while 1:
         if secure:
-            val = input('\nEnter secure port number [{}]: '.format(default_port))
+            val = input('\nEnter secure port number [{}]: '.format(default_port)).rstrip()
         else:
-            val = input('\nEnter port number [{}]: '.format(default_port))
+            val = input('\nEnter port number [{}]: '.format(default_port)).rstrip()
 
         if val != "" or default_port == "":
             # Validate port is number and in a valid range
@@ -101,8 +106,7 @@ class SetupDs(object):
         self.dryrun = dryrun
         # Expose the logger to our children.
         self.log = log.getChild('SetupDs')
-        if self.verbose:
-            self.log.info('Running setup with verbose')
+        self.log.debug('Running setup with verbose')
         # This will indicate that start / stop / status should bypass systemd.
         self.containerised = containerised
 
@@ -139,30 +143,27 @@ class SetupDs(object):
         general_options.verify()
         general = general_options.collect()
 
-        if self.verbose:
-            self.log.info("Configuration general %s", general)
+        self.log.debug("Configuration general %s", general)
 
         slapd_options = Slapd2Base(self.log)
         slapd_options.parse_inf_config(config)
         slapd_options.verify()
         slapd = slapd_options.collect()
 
-        if self.verbose:
-            self.log.info("Configuration slapd %s", slapd)
+        self.log.debug("Configuration slapd %s", slapd)
 
         backends = []
         for section in config.sections():
             if section.startswith('backend-'):
                 backend_options = Backend2Base(self.log, section)
                 backend_options.parse_inf_config(config)
-
                 suffix = config.get(section, 'suffix', fallback='')
                 if suffix != '':
-                    be = {}
-
                     # Suffix
+                    be = {}
                     be[BACKEND_NAME] = section.replace('backend-', '')
-                    be[BACKEND_SUFFIX] = config.get(section, 'suffix')
+                    be[BACKEND_SUFFIX] = suffix
+                    be['create_suffix_entry'] = config.get(section, 'create_suffix_entry', fallback=False)
 
                     # Sample entries
                     sample_entries = config.get(section, 'sample_entries', fallback='no')
@@ -183,8 +184,7 @@ class SetupDs(object):
                     # Add this backend to the list
                     backends.append(be)
 
-        if self.verbose:
-            self.log.info("Configuration backends %s", backends)
+        self.log.debug("Configuration backends %s", backends)
 
         return (general, slapd, backends)
 
@@ -200,6 +200,36 @@ class SetupDs(object):
         else:
             assert_c(False, "Unsupported config_version in section [general]")
 
+    def _remove_failed_install(self, serverid):
+        """The install failed, remove the scraps
+        :param serverid - The server ID of the instance
+        """
+        inst = DirSrv()
+
+        # Allocate the instance based on name
+        insts = []
+        insts = inst.list(serverid=serverid)
+
+        if len(insts) != 1:
+            log.error("No such instance to remove {}".format(serverid))
+            return
+        inst.allocate(insts[0])
+        remove_ds_instance(inst, force=True)
+
+    def _server_id_taken(self, serverid, prefix='/usr'):
+        """Check if instance name is already taken
+        :param serverid - name of the server instance
+        :param prefix - name of prefix build location
+        :return True - if the server id is already in use
+                False - if the server id is available
+        """
+        if prefix != "/usr":
+            inst_dir = prefix + "/etc/dirsrv/slapd-" + serverid
+        else:
+            inst_dir = "/etc/dirsrv/slapd-" + serverid
+
+        return os.path.isdir(inst_dir)
+
     def create_from_cli(self):
         # Ask questions to generate general, slapd, and backends
         print('Install Directory Server (interactive mode)')
@@ -226,6 +256,7 @@ class SetupDs(object):
                  'sysconf_dir': ds_paths.sysconf_dir,
                  'data_dir': ds_paths.data_dir,
                  'local_state_dir': ds_paths.local_state_dir,
+                 'ldapi': ds_paths.ldapi,
                  'lib_dir': ds_paths.lib_dir,
                  'run_dir': ds_paths.run_dir,
                  'tmp_dir': ds_paths.tmp_dir,
@@ -240,19 +271,19 @@ class SetupDs(object):
                  'schema_dir': ds_paths.schema_dir}
 
         # Start asking questions, beginning with the hostname...
-        val = input('\nEnter system\'s hostname [{}]: '.format(general['full_machine_name']))
+        val = input('\nEnter system\'s hostname [{}]: '.format(general['full_machine_name'])).rstrip()
         if val != "":
             general['full_machine_name'] = val
 
         # Strict host name checking
         msg = ("\nUse strict hostname verification (set to \"no\" if using GSSAPI behind a load balancer) [yes]: ")
         while 1:
-            val = input(msg)
+            val = input(msg).rstrip().lower()
             if val != "":
-                if val.lower() == "no" or val.lower() == "n":
+                if val == "no" or val == "n":
                     slapd['strict_host_checking'] = False
                     break
-                if val.lower() == "yes" or val.lower() == "y":
+                if val == "yes" or val == "y":
                     # Use default
                     break
 
@@ -265,8 +296,16 @@ class SetupDs(object):
         # Instance name - adjust defaults once set
         while 1:
             slapd['instance_name'] = general['full_machine_name'].split('.', 1)[0]
-            val = input('\nEnter the instance name [{}]: '.format(slapd['instance_name']))
+
+            # Check if default server id is taken
+            if self._server_id_taken(slapd['instance_name'], prefix=slapd['prefix']):
+                slapd['instance_name'] = ""
+
+            val = input('\nEnter the instance name [{}]: '.format(slapd['instance_name'])).rstrip()
             if val != "":
+                if not all(ord(c) < 128 for c in val):
+                    print("Server identifier can not contain non ascii characters")
+                    continue
                 if ' ' in val:
                     print("Server identifier can not contain a space")
                     continue
@@ -281,21 +320,18 @@ class SetupDs(object):
                     continue
 
                 # Check if server id is taken
-                inst_dir = slapd['config_dir'] + "/" + val
-                if os.path.isdir(inst_dir):
+                if self._server_id_taken(val, prefix=slapd['prefix']):
                     print("Server identifier \"{}\" is already taken, please choose a new name".format(val))
                     continue
 
                 # instance name is good
                 slapd['instance_name'] = val
                 break
+            elif slapd['instance_name'] == "":
+                continue
             else:
                 # Check if default server id is taken
-                if slapd['prefix'] != "/usr":
-                    inst_dir = slapd['prefix'] + slapd['config_dir'] + "/" + slapd['instance_name']
-                else:
-                    inst_dir = slapd['config_dir'] + "/" + slapd['instance_name']
-                if os.path.isdir(inst_dir):
+                if self._server_id_taken(slapd['instance_name'], prefix=slapd['prefix']):
                     print("Server identifier \"{}\" is already taken, please choose a new name".format(slapd['instance_name']))
                     continue
                 break
@@ -315,12 +351,12 @@ class SetupDs(object):
 
         # Self-Signed Cert DB
         while 1:
-            val = input('\nCreate self-signed certificate database [yes]: ')
+            val = input('\nCreate self-signed certificate database [yes]: ').rstrip().lower()
             if val != "":
-                if val.lower() == 'no' or val.lower() == "n":
+                if val== 'no' or val == "n":
                     slapd['self_sign_cert'] = False
                     break
-                elif val.lower() == "yes" or val.lower() == "y":
+                elif val == "yes" or val == "y":
                     # Default value is already yes
                     break
                 else:
@@ -338,10 +374,12 @@ class SetupDs(object):
                 # Port 636 is already taken, pick another port
                 port = get_port(slapd['secure_port'], "", secure=True)
             slapd['secure_port'] = port
+        else:
+            slapd['secure_port'] = False
 
         # Root DN
         while 1:
-            val = input('\nEnter Directory Manager DN [{}]: '.format(slapd['root_dn']))
+            val = input('\nEnter Directory Manager DN [{}]: '.format(slapd['root_dn'])).rstrip()
             if val != '':
                 # Validate value is a DN
                 if is_a_dn(val, allow_anon=False):
@@ -356,12 +394,12 @@ class SetupDs(object):
 
         # Root DN Password
         while 1:
-            rootpw1 = getpass.getpass('\nEnter the Directory Manager password: ')
+            rootpw1 = getpass.getpass('\nEnter the Directory Manager password: ').rstrip()
             if rootpw1 == '':
                 print('Password can not be empty')
                 continue
 
-            rootpw2 = getpass.getpass('Confirm the Directory Manager Password: ')
+            rootpw2 = getpass.getpass('Confirm the Directory Manager Password: ').rstrip()
             if rootpw1 != rootpw2:
                 print('Passwords do not match')
                 continue
@@ -382,7 +420,7 @@ class SetupDs(object):
                 suffix += ",dc=" + comp
 
         while 1:
-            val = input("\nEnter the database suffix (or enter \"none\" to skip) [{}]: ".format(suffix))
+            val = input("\nEnter the database suffix (or enter \"none\" to skip) [{}]: ".format(suffix)).rstrip()
             if val != '':
                 if val.lower() == "none":
                     # No database, no problem
@@ -398,29 +436,47 @@ class SetupDs(object):
                 backend['suffix'] = suffix
                 break
 
-        # Add sample entries?
-        while 1:
-            val = input("\nCreate sample entries in the suffix [no]: ".format(suffix))
-            if val != "":
-                if val.lower() == "no" or val.lower() == "n":
-                    break
-                if val.lower() == "yes" or val.lower() == "y":
-                    backend['sample_entries'] = INSTALL_LATEST_CONFIG
+        # Add sample entries or root suffix entry?
+        if len(backends) > 0:
+            while 1:
+                val = input("\nCreate sample entries in the suffix [no]: ").rstrip().lower()
+                if val != "":
+                    if val == "no" or val == "n":
+                        break
+                    if val == "yes" or val == "y":
+                        backend['sample_entries'] = INSTALL_LATEST_CONFIG
+                        break
+
+                    # Unknown value
+                    print ("Value \"{}\" is invalid, please use \"yes\" or \"no\"".format(val))
+                    continue
+                else:
                     break
 
-                # Unknown value
-                print ("Value \"{}\" is invalid, please use \"yes\" or \"no\"".format(val))
-                continue
-            else:
-                break
+            if 'sample_entries' not in backend:
+                # Check if they want to create the root node entry instead
+                while 1:
+                    val = input("\nCreate just the top suffix entry [no]: ").rstrip().lower()
+                    if val != "":
+                        if val == "no" or val == "n":
+                            break
+                        if val == "yes" or val == "y":
+                            backend['create_suffix_entry'] = True
+                            break
+
+                        # Unknown value
+                        print ("Value \"{}\" is invalid, please use \"yes\" or \"no\"".format(val))
+                        continue
+                    else:
+                        break
 
         # Are you ready?
         while 1:
-            val = input('\nAre you ready to install? [no]: ')
-            if val == '' or val.lower() == "no" or val.lower() == 'n':
+            val = input('\nAre you ready to install? [no]: ').rstrip().lower()
+            if val == '' or val == "no" or val == 'n':
                 print('Aborting installation...')
                 sys.exit(0)
-            elif val.lower() == 'yes' or val.lower() == 'y':
+            elif val == 'yes' or val == 'y':
                 # lets do it!
                 break
             else:
@@ -547,8 +603,6 @@ class SetupDs(object):
             assert_c('cn' in be)
         # Add an assertion that we don't double suffix or double CN here ...
 
-
-
     def create_from_args(self, general, slapd, backends=[], extra=None):
         """
         Actually does the setup. this is what you want to call as an api.
@@ -557,26 +611,29 @@ class SetupDs(object):
         self.log.info("\nStarting installation...")
 
         # Check we have privs to run
-        if self.verbose:
-            self.log.info("READY: Preparing installation for %s...", slapd['instance_name'])
+        self.log.debug("READY: Preparing installation for %s...", slapd['instance_name'])
 
         self._prepare_ds(general, slapd, backends)
         # Call our child api to prepare itself.
         self._prepare(extra)
 
-        if self.verbose:
-            self.log.info("READY: Beginning installation for %s...", slapd['instance_name'])
+        self.log.debug("READY: Beginning installation for %s...", slapd['instance_name'])
 
         if self.dryrun:
             self.log.info("NOOP: Dry run requested")
         else:
             # Actually trigger the installation.
-            self._install_ds(general, slapd, backends)
+            try:
+                self._install_ds(general, slapd, backends)
+            except ValueError as e:
+                self.log.fatal("Error: " + str(e) + ", removing incomplete installation...")
+                self._remove_failed_install(slapd['instance_name'])
+                raise ValueError("Instance creation failed!")
+
             # Call the child api to do anything it needs.
             self._install(extra)
-        if self.verbose:
-            self.log.info("FINISH: Completed installation for %s", slapd['instance_name'])
-        else:
+        self.log.debug("FINISH: Completed installation for %s", slapd['instance_name'])
+        if not self.verbose:
             self.log.info("Completed installation for %s", slapd['instance_name'])
 
     def _install_ds(self, general, slapd, backends):
@@ -593,10 +650,12 @@ class SetupDs(object):
             for line in template_init.readlines():
                 initconfig += line.replace('{{', '{', 1).replace('}}', '}', 1).replace('-', '_')
         try:
-            os.makedirs("%s/sysconfig" % slapd['sysconf_dir'], mode=0o775)
+            # /etc/sysconfig
+            os.makedirs("%s" % slapd['initconfig_dir'], mode=0o770)
         except FileExistsError:
             pass
-        with open("%s/sysconfig/dirsrv-%s" % (slapd['sysconf_dir'], slapd['instance_name']), 'w') as f:
+        sysconfig_filename = "%s/dirsrv-%s" % (slapd['initconfig_dir'], slapd['instance_name'])
+        with open(sysconfig_filename, 'w') as f:
             f.write(initconfig.format(
                 SERVER_DIR=slapd['lib_dir'],
                 SERVERBIN_DIR=slapd['sbin_dir'],
@@ -606,17 +665,24 @@ class SetupDs(object):
                 DS_ROOT='',
                 PRODUCT_NAME='slapd',
             ))
+        os.chmod(sysconfig_filename, 0o440)
+        os.chown(sysconfig_filename, slapd['user_uid'], slapd['group_gid'])
 
         # Create all the needed paths
-        # we should only need to make bak_dir, cert_dir, config_dir, db_dir, ldif_dir, lock_dir, log_dir, run_dir? schema_dir,
+        # we should only need to make bak_dir, cert_dir, config_dir, db_dir, ldif_dir, lock_dir, log_dir, run_dir?
         for path in ('backup_dir', 'cert_dir', 'config_dir', 'db_dir', 'ldif_dir', 'lock_dir', 'log_dir', 'run_dir'):
-            if self.verbose:
-                self.log.info("ACTION: creating %s", slapd[path])
+            self.log.debug("ACTION: creating %s", slapd[path])
             try:
-                os.makedirs(slapd[path], mode=0o775)
+                os.umask(0o007)  # For parent dirs that get created -> sets 770 for perms
+                os.makedirs(slapd[path], mode=0o770)
             except OSError:
                 pass
             os.chown(slapd[path], slapd['user_uid'], slapd['group_gid'])
+
+        # /var/lock/dirsrv needs special attention...
+        parentdir = os.path.abspath(os.path.join(slapd['lock_dir'], os.pardir))
+        os.chown(parentdir, slapd['user_uid'], slapd['group_gid'])
+
         ### Warning! We need to down the directory under db too for .restore to work.
         # See dblayer.c for more!
         db_parent = os.path.join(slapd['db_dir'], '..')
@@ -629,35 +695,39 @@ class SetupDs(object):
 
         _ds_shutil_copytree(os.path.join(slapd['sysconf_dir'], 'dirsrv/schema'), slapd['schema_dir'])
         os.chown(slapd['schema_dir'], slapd['user_uid'], slapd['group_gid'])
+        os.chmod(slapd['schema_dir'], 0o770)
 
         # Copy in the collation
         srcfile = os.path.join(slapd['sysconf_dir'], 'dirsrv/config/slapd-collations.conf')
         dstfile = os.path.join(slapd['config_dir'], 'slapd-collations.conf')
         shutil.copy2(srcfile, dstfile)
         os.chown(dstfile, slapd['user_uid'], slapd['group_gid'])
+        os.chmod(dstfile, 0o440)
 
         # Copy in the certmap configuration
         srcfile = os.path.join(slapd['sysconf_dir'], 'dirsrv/config/certmap.conf')
         dstfile = os.path.join(slapd['config_dir'], 'certmap.conf')
         shutil.copy2(srcfile, dstfile)
         os.chown(dstfile, slapd['user_uid'], slapd['group_gid'])
+        os.chmod(dstfile, 0o440)
 
         # If we are on the correct platform settings, systemd
         if general['systemd'] and not self.containerised:
             # Should create the symlink we need, but without starting it.
-            subprocess.check_call(["/usr/bin/systemctl",
-                                    "enable",
-                                    "dirsrv@%s" % slapd['instance_name']])
+            subprocess.check_call(["systemctl",
+                                   "enable",
+                                   "dirsrv@%s" % slapd['instance_name']])
 
-        # Setup tmpfiles_d
-        tmpfile_d = ds_paths.tmpfiles_d + "/dirsrv-" + slapd['instance_name'] + ".conf"
-        with open(tmpfile_d, "w") as TMPFILE_D:
-            TMPFILE_D.write("d {} 0770 {} {}\n".format(slapd['run_dir'], slapd['user'], slapd['group']))
-            TMPFILE_D.write("d {} 0770 {} {}\n".format(slapd['lock_dir'].replace("slapd-" + slapd['instance_name'], ""),
-                                                       slapd['user'], slapd['group']))
-            TMPFILE_D.write("d {} 0770 {} {}\n".format(slapd['lock_dir'], slapd['user'], slapd['group']))
+            # Setup tmpfiles_d
+            tmpfile_d = ds_paths.tmpfiles_d + "/dirsrv-" + slapd['instance_name'] + ".conf"
+            with open(tmpfile_d, "w") as TMPFILE_D:
+                TMPFILE_D.write("d {} 0770 {} {}\n".format(slapd['run_dir'], slapd['user'], slapd['group']))
+                TMPFILE_D.write("d {} 0770 {} {}\n".format(slapd['lock_dir'].replace("slapd-" + slapd['instance_name'], ""),
+                                                           slapd['user'], slapd['group']))
+                TMPFILE_D.write("d {} 0770 {} {}\n".format(slapd['lock_dir'], slapd['user'], slapd['group']))
 
         # Else we need to detect other init scripts?
+        # WB: No, we just install and assume that docker will start us ...
 
         # Bind sockets to our type?
 
@@ -670,17 +740,14 @@ class SetupDs(object):
         if len(backends) > 0:
             ds_suffix = backends[0]['nsslapd-suffix']
 
-
         # Create certdb in sysconfidir
-        if self.verbose:
-            self.log.info("ACTION: Creating certificate database is %s", slapd['cert_dir'])
+        self.log.debug("ACTION: Creating certificate database is %s", slapd['cert_dir'])
 
         # Create dse.ldif with a temporary root password.
         # The template is in slapd['data_dir']/dirsrv/data/template-dse.ldif
         # Variables are done with %KEY%.
         # You could cheat and read it in, do a replace of % to { and } then use format?
-        if self.verbose:
-            self.log.info("ACTION: Creating dse.ldif")
+        self.log.debug("ACTION: Creating dse.ldif")
         dse = ""
         with open(os.path.join(slapd['data_dir'], 'dirsrv', 'data', 'template-dse.ldif')) as template_dse:
             for line in template_dse.readlines():
@@ -752,10 +819,18 @@ class SetupDs(object):
             csr = tlsdb.create_rsa_key_and_csr()
             (ca, crt) = ssca.rsa_ca_sign_csr(csr)
             tlsdb.import_rsa_crt(ca, crt)
+            if not self.containerised and general['selinux']:
+                # Set selinux port label
+                selinux_label_port(slapd['secure_port'])
 
-        ## LAST CHANCE, FIX PERMISSIONS.
-        # Selinux fixups?
-        # Restorecon of paths?
+        # Do selinux fixups
+        if not self.containerised and general['selinux']:
+            selinux_paths = ('backup_dir', 'cert_dir', 'config_dir', 'db_dir', 'ldif_dir',
+                             'lock_dir', 'log_dir', 'run_dir', 'schema_dir', 'tmp_dir')
+            for path in selinux_paths:
+                selinux_restorecon(slapd[path])
+
+            selinux_label_port(slapd['port'])
 
         # Start the server
         # Make changes using the temp root
@@ -771,17 +846,32 @@ class SetupDs(object):
         base_config_inst.apply_config(install=True)
 
         # Setup TLS with the instance.
+
+        # We *ALWAYS* set secure port, even if security is off, because it breaks
+        # tests with standalone.enable_tls if we do not. It's only when security; on
+        # that we actually start listening on it.
+        ds_instance.config.set('nsslapd-secureport', '%s' % slapd['secure_port'])
         if slapd['self_sign_cert']:
-            ds_instance.config.set('nsslapd-secureport', '%s' % slapd['secure_port'])
             ds_instance.config.set('nsslapd-security', 'on')
 
         # Create the backends as listed
         # Load example data if needed.
         for backend in backends:
+            is_sample_entries_in_props = "sample_entries" in backend
+            create_suffix_entry_in_props = backend.pop('create_suffix_entry', False)
             ds_instance.backends.create(properties=backend)
+            if not is_sample_entries_in_props and create_suffix_entry_in_props:
+                domain = create_base_domain(ds_instance, backend['nsslapd-suffix'])
+                # Set basic ACI
+                domain.add('aci', [
+                    # Allow reading the base domain object
+                    '(targetattr="dc || description || objectClass")(targetfilter="(objectClass=domain)")(version 3.0; acl "Enable anyone domain read"; allow (read, search, compare)(userdn="ldap:///anyone");)',
+                    # Allow reading the ou
+                    '(targetattr="ou || objectClass")(targetfilter="(objectClass=organizationalUnit)")(version 3.0; acl "Enable anyone ou read"; allow (read, search, compare)(userdn="ldap:///anyone");)'
+                ])
 
         # Initialise ldapi socket information. IPA expects this ....
-        ldapi_path = slapd['run_dir'].replace('dirsrv', 'slapd-' + slapd['instance_name'] + '.socket')
+        ldapi_path = os.path.join(slapd['local_state_dir'], "run/slapd-%s.socket" % slapd['instance_name'])
         ds_instance.config.set('nsslapd-ldapifilepath', ldapi_path)
         ds_instance.config.set('nsslapd-ldapilisten', 'on')
         ds_instance.config.set('nsslapd-ldapiautobind', 'on')
