@@ -44,7 +44,6 @@ SER_PROPNAME_TO_ATTRNAME = {SER_HOST: 'nsslapd-localhost',
 #
 # Those WITHOUT related attribute name
 #
-SER_REALM = 'krb5_realm'
 SER_SERVERID_PROP = 'server-id'
 SER_GROUP_ID = 'group-id'
 SER_DEPLOYED_DIR = 'deployed-dir'
@@ -110,11 +109,11 @@ BACKEND_CHAIN_BIND_DN = 'chain-bind-dn'
 BACKEND_CHAIN_BIND_PW = 'chain-bind-pw'
 BACKEND_CHAIN_URLS = 'chain-urls'
 BACKEND_STATS = 'stats'
-BACKEND_SUFFIX = 'suffix'
 BACKEND_SAMPLE_ENTRIES = 'sample_entries'
 
 BACKEND_OBJECTCLASS_VALUE = 'nsBackendInstance'
 
+# THIS NEEDS TO BE REMOVED. HACKS!!!!
 BACKEND_PROPNAME_TO_ATTRNAME = {BACKEND_SUFFIX: 'nsslapd-suffix',
                                 BACKEND_NAME: 'cn',
                                 BACKEND_READONLY: 'nsslapd-readonly',
