@@ -591,23 +591,23 @@ class ReplicaLegacy(object):
             status = entry.nsds5ReplicaLastInitStatus
             if not refresh:  # done - check status
                 if not status:
-                    print("No status yet")
+                    self.log.info("No status yet")
                 elif status.find(ensure_bytes("replica busy")) > -1:
-                    print("Update failed - replica busy - status", status)
+                    self.log.info("Update failed - replica busy - status", status)
                     done = True
                     hasError = 2
                 elif status.find(ensure_bytes("Total update succeeded")) > -1:
-                    print("Update succeeded: status ", status)
+                    self.log.info("Update succeeded: status ", status)
                     done = True
                 elif inprogress.lower() == ensure_bytes('true'):
-                    print("Update in progress yet not in progress: status ",
+                    self.log.info("Update in progress yet not in progress: status ",
                           status)
                 else:
-                    print("Update failed: status", status)
+                    self.log.info("Update failed: status", status)
                     hasError = 1
                     done = True
-            elif self.verbose:
-                print("Update in progress: status", status)
+            else:
+                self.log.debug("Update in progress: status", status)
 
         return done, hasError
 
@@ -1012,9 +1012,13 @@ class Replica(DSLdapObject):
         :raises: ValueError - If replica is not promoted
         """
 
-
+        # Set the bind dn, use the existing one if it exists
         if binddn is None and binddn_group is None:
-            binddn = defaultProperties[REPLICATION_BIND_DN]
+            curr_dn = self.get_attr_val(REPL_BINDDN)
+            if curr_dn is None:
+                binddn = defaultProperties[REPLICATION_BIND_DN]
+            else:
+                binddn = curr_dn
 
         # Check the role type
         replicarole = self.get_role()
@@ -1069,15 +1073,15 @@ class Replica(DSLdapObject):
                 raise ValueError('Failed to update replica: ' + str(e))
         elif replicarole == ReplicaRole.CONSUMER and newrole == ReplicaRole.MASTER:
             try:
-                self.apply_mods([(REPL_TYPE, str(REPLICA_RDWR_TYPE)),
-                                 (REPL_FLAGS, str(REPLICA_FLAGS_WRITE)),
-                                 (REPL_ID, str(rid))])
+                self.replace_many([(REPL_TYPE, str(REPLICA_RDWR_TYPE)),
+                                   (REPL_FLAGS, str(REPLICA_FLAGS_WRITE)),
+                                   (REPL_ID, str(rid))])
             except ldap.LDAPError as e:
                 raise ValueError('Failed to update replica: ' + str(e))
         elif replicarole == ReplicaRole.HUB and newrole == ReplicaRole.MASTER:
             try:
-                self.apply_mods([(REPL_TYPE, str(REPLICA_RDWR_TYPE)),
-                                 (REPL_ID, str(rid))])
+                self.replace_many([(REPL_TYPE, str(REPLICA_RDWR_TYPE)),
+                                   (REPL_ID, str(rid))])
             except ldap.LDAPError as e:
                 raise ValueError('Failed to update replica: ' + str(e))
 
@@ -1099,15 +1103,15 @@ class Replica(DSLdapObject):
         # Demote it - set the replica type, flags and rid
         if replicarole == ReplicaRole.MASTER and newrole == ReplicaRole.HUB:
             try:
-                self.apply_mods([(REPL_TYPE, str(REPLICA_RDONLY_TYPE)),
-                                 (REPL_ID, str(CONSUMER_REPLICAID))])
+                self.replace_many([(REPL_TYPE, str(REPLICA_RDONLY_TYPE)),
+                                   (REPL_ID, str(CONSUMER_REPLICAID))])
             except ldap.LDAPError as e:
                 raise ValueError('Failed to update replica: ' + str(e))
         elif replicarole == ReplicaRole.MASTER and newrole == ReplicaRole.CONSUMER:
             try:
-                self.apply_mods([(REPL_TYPE, str(REPLICA_RDONLY_TYPE)),
-                                 (REPL_FLAGS, str(REPLICA_FLAGS_RDONLY)),
-                                 (REPL_ID, str(CONSUMER_REPLICAID))])
+                self.replace_many([(REPL_TYPE, str(REPLICA_RDONLY_TYPE)),
+                                   (REPL_FLAGS, str(REPLICA_FLAGS_RDONLY)),
+                                   (REPL_ID, str(CONSUMER_REPLICAID))])
             except ldap.LDAPError as e:
                 raise ValueError('Failed to update replica: ' + str(e))
         elif replicarole == ReplicaRole.HUB and newrole == ReplicaRole.CONSUMER:
@@ -1238,6 +1242,14 @@ class Replica(DSLdapObject):
         """
         self.replace('nsds5task', 'cl2ldif')
 
+    def get_suffix(self):
+        """Return the suffix
+        """
+        if self._suffix is None:
+            self._populate_suffix()
+
+        return self._suffix
+
 
 class Replicas(DSLdapObjects):
     """Replica DSLdapObjects for all replicas
