@@ -7,22 +7,18 @@
 # --- END COPYRIGHT BLOCK ---
 
 import pytest
-
-from lib389 import DirSrv
-from lib389.cli_base import LogCapture, FakeArgs
-
-from lib389.instance.setup import SetupDs
-from lib389.instance.options import General2Base, Slapd2Base
+import sys
+import io
+from lib389.cli_base import LogCapture
 from lib389._constants import *
-
 from lib389.topologies import create_topology, DEBUGGING
-
-from lib389.utils import generate_ds_params
 from lib389.configurations import get_sample_entries
 
+
 @pytest.fixture(scope="module")
 def topology(request):
     topology = create_topology({ReplicaRole.STANDALONE: 1}, None)
+
     def fin():
         if DEBUGGING:
             topology.standalone.stop()
@@ -33,12 +29,13 @@ def topology(request):
     topology.logcap = LogCapture()
     return topology
 
+
 @pytest.fixture(scope="module")
 def topology_be_latest(request):
     topology = create_topology({ReplicaRole.STANDALONE: 1}, None)
-    be = topology.standalone.backends.create(properties={
+    topology.standalone.backends.create(properties={
         'cn': 'userRoot',
-        'suffix' : DEFAULT_SUFFIX,
+        'suffix': DEFAULT_SUFFIX,
     })
     # Now apply sample entries
     centries = get_sample_entries(INSTALL_LATEST_CONFIG)
@@ -55,12 +52,13 @@ def topology_be_latest(request):
     topology.logcap = LogCapture()
     return topology
 
+
 @pytest.fixture(scope="module")
 def topology_be_001003006(request):
     topology = create_topology({ReplicaRole.STANDALONE: 1}, None)
-    be = topology.standalone.backends.create(properties={
+    topology.standalone.backends.create(properties={
         'cn': 'userRoot',
-        'suffix' : DEFAULT_SUFFIX,
+        'suffix': DEFAULT_SUFFIX,
     })
     # Now apply sample entries
     centries = get_sample_entries('001003006')
@@ -78,3 +76,21 @@ def topology_be_001003006(request):
     return topology
 
 
+def check_output(some_string, missing=False, ignorecase=True):
+    """Check the output of captured STDOUT.  This assumes "sys.stdout = io.StringIO()"
+    otherwise there would be nothing to read
+    :param some_string - text to search for in output
+    :param missing - test if some_string is NOT present in output
+    :param ignorecase - Set whether to ignore the character case in both the output
+                        and some_string
+    """
+    output = sys.stdout.getvalue()
+    if ignorecase:
+        output = output.lower()
+        some_string = some_string.lower()
+    if missing:
+        assert(some_string not in output)
+    else:
+        assert(some_string in output)
+    # clear buffer
+    sys.stdout = io.StringIO()
